/// <reference types="react" />
import * as react from 'react';
import react__default from 'react';
import * as _backstage_catalog_model from '@backstage/catalog-model';
import { Entity } from '@backstage/catalog-model';
import * as _backstage_core_plugin_api from '@backstage/core-plugin-api';
import { ApiRef } from '@backstage/core-plugin-api';

declare const entityContentRouteRef: any;
declare const firebaseFunctionsPlugin: _backstage_core_plugin_api.BackstagePlugin<{
    entityContent: any;
}, {}>;
declare const EntityFirebaseFunctionsContent: (_props: {
    entity?: _backstage_catalog_model.Entity | undefined;
}) => JSX.Element;
declare const EntityFirebaseFunctionsCard: react.FC<{
    entity?: _backstage_catalog_model.Entity | undefined;
}>;

declare type FunctionData = {
    name: string;
    urlTrigger: string;
    status: string;
    runtime: string;
    availableMemoryMb: number;
    updateTime: string;
    region: string;
    project: string;
    envVariables: Record<string, string>;
    labels: Record<string, string>;
    fullName: string;
};

declare const firebaseFunctionsApiRef: ApiRef<FirebaseFunctionsApi>;
declare type ListFunctionsArgs = {
    googleIdToken: string;
    projects: string[];
};
declare type ListFunctionsType = (input: ListFunctionsArgs) => Promise<{
    functionData: FunctionData[];
}>;
declare type GetFunctionArgs = {
    googleIdToken: string;
    functionSlug: string;
};
declare type GetFunctionType = (input: GetFunctionArgs) => Promise<FunctionData>;
declare type FirebaseFunctionsApi = {
    listFunctions: ListFunctionsType;
    getFunction: GetFunctionType;
};

declare class FirebaseFunctionsClient implements FirebaseFunctionsApi {
    getFunction({ googleIdToken, functionSlug }: GetFunctionArgs): Promise<{
        name: string;
        urlTrigger: string;
        status: string;
        updateTime: string;
        runtime: string;
        availableMemoryMb: number;
        project: string;
        region: string;
        labels: Record<string, string>;
        envVariables: Record<string, string>;
        fullName: string;
    }>;
    listFunctions({ googleIdToken, projects }: ListFunctionsArgs): Promise<{
        functionData: FunctionData[];
    }>;
}

declare const isFirebaseFunctionsAvailable: (entity: Entity) => boolean;
declare type Props$1 = {
    /** @deprecated The entity is now grabbed from context instead */
    entity?: Entity;
};
declare const Router: (_props: Props$1) => JSX.Element;

declare const isOnlyOneFirebaseFunction: (entity: Entity) => boolean;
declare const isMoreThanOneFirebaseFunction: (entity: Entity) => boolean;

declare type Props = {
    /** @deprecated The entity is now grabbed from context instead */
    entity?: Entity;
};
declare const FirebaseFunctionWidget: react__default.FC<Props>;

export { EntityFirebaseFunctionsCard, EntityFirebaseFunctionsContent, FirebaseFunctionWidget, FirebaseFunctionsApi, FirebaseFunctionsClient, GetFunctionArgs, GetFunctionType, ListFunctionsArgs, ListFunctionsType, Router, entityContentRouteRef, firebaseFunctionsApiRef, firebaseFunctionsPlugin, isFirebaseFunctionsAvailable, isMoreThanOneFirebaseFunction, isOnlyOneFirebaseFunction, isFirebaseFunctionsAvailable as isPluginApplicableToEntity };
